==> idoit-documents-1.4.1.zip: src/classes/modules/document/export/isys_document_export_pdf.class.php <==
<?php

/**
 * i-doit
 *
 * Exports HTML to PDF.
 *
 * @package     i-doit
 * @subpackage  Modules
 * @author      Selcuk Kekec <skekec@i-doit.com>
 * @version     1.0.0
 * @copyright   synetics GmbH
 * @license     http://www.i-doit.com/license
 * @since       i-doit 1.4.0
 */
class isys_document_export_pdf extends isys_document_export
{
    /**
     * Generated HTML for the library.
     *
     * @var  string
     */
    protected $m_html = '';

    /**
     * Export Document to pdf.
     *
     * @param   string $p_filename
     *
     * @return  isys_document_export_pdf
     */
    public function export($p_filename = '')
    {
        // Initialize formatter with options.
        $this->m_formatter->initialize($this->m_options);

        $this->prepareStylesheet();

        $this->m_formatter->beforeExport();

        // Set CSS styling in the formatter, since TCPDF will need to append this chunk in every "writeHTML" call.
        $this->m_formatter->setStyle($this->get_style(), 0, 0);

        /**
         * Add chapters html text to our document
         *
         * @var $l_model isys_document_export_model
         */
        foreach ($this->m_models as $l_index => $l_model) {
            // Determine if chapter shall be in a new page or not
            if ($l_model->get_new_page() && intval($l_model->get_pos()) !== 1) {
                $this->m_formatter->addNewPage();
            }

            $l_text = $l_model->get_text();

            // Attach headline to formatted document.
            if ($this->m_options['general.headlines']) {
                $this->m_formatter->addHeadline($l_model->get_title(), $l_model->get_pos(), $l_model->get_level());

                // We add "div" elements around the text, so that TCPDF will add more margin around the blocks.
                $l_text = '<div>' . $l_text . '</div>';
            }

            // Attach content to formatted document.
            $this->m_formatter->addContent($l_text, $l_model->get_pos(), $l_model->get_level());
        }

        $this->m_formatter->afterExport();

        return $this;
    }

    /**
     *
     * @param   string    $p_filename
     * @param string|null $filePath
     *
     * @return  isys_document_export_pdf
     */
    public function write($p_filename, $filePath = null)
    {
        $this->m_formatter->save(($filePath !== null ? rtrim($filePath, '/') . '/' . $p_filename . '.' . $this->get_file_extension() : $this->get_filepath($p_filename)));

        return $this;
    }

    /**
     *
     * @param   string  $p_filename
     * @param   boolean $p_inline
     *
     * @return  isys_document_export_pdf
     */
    public function send($p_filename, $p_inline = false)
    {
        $this->m_formatter->send($p_filename . '.pdf', $p_inline);

        return $this;
    }

    /**
     * Mimetype of our file.
     *
     * @return  string
     */
    public function get_mimetype()
    {
        return 'application/pdf';
    }

    /**
     * Extension.
     *
     * @return  string
     */
    public function get_file_extension()
    {
        return 'pdf';
    }

    /**
     * Initialize.
     */
    protected function init()
    {
        // Setting default styles.
        $this->prepareStylesheet();
    }

    /**
     * @return void
     */
    private function prepareStylesheet()
    {
        // @see  DOKU-304 Preparing some default styles.
        $style = 'p { margin: 0 0 10px 0; }
            table { width: 100%; } 
            code { font-family: courier; }
            ins { text-decoration: underline; } 
            blockquote { padding: 5px 20px; margin-left: 20px; border-left: 3px solid #ccc; } 
            .marker { background-color: #ff0; } 
            .font-monospace { font-family: courier; } ';

        // @see  DOKU-308  Pass the defined headline-sizes.
        foreach ($this->m_options as $key => $value) {
            if (preg_match('~general\.h([1-6])\.size~', $key, $matches)) {
                $style .= 'h' . $matches[1] . ' { font-size: ' . $value . 'pt; } ';
            }
        }

        $this->set_style($style);
    }
}

==> idoit-documents-1.4.3.zip: src/classes/modules/document/export/isys_document_export_pdf.class.php <==
<?php

/**
 * i-doit
 *
 * Exports HTML to PDF.
 *
 * @package     i-doit
 * @subpackage  Modules
 * @author      Selcuk Kekec <skekec@i-doit.com>
 * @version     1.0.0
 * @copyright   synetics GmbH
 * @license     http://www.i-doit.com/license
 * @since       i-doit 1.4.0
 */
class isys_document_export_pdf extends isys_document_export
{
    /**
     * Generated HTML for the library.
     *
     * @var  string
     */
    protected $m_html = '';

    /**
     * Export Document to pdf.
     *
     * @param   string $p_filename
     *
     * @return  isys_document_export_pdf
     */
    public function export($p_filename = '')
    {
        // Initialize formatter with options.
        $this->m_formatter->initialize($this->m_options);

        $this->prepareStylesheet();

        $this->m_formatter->beforeExport();

        // Set CSS styling in the formatter, since TCPDF will need to append this chunk in every "writeHTML" call.
        $this->m_formatter->setStyle($this->get_style(), 0, 0);

        /**
         * Add chapters html text to our document
         *
         * @var $l_model isys_document_export_model
         */
        foreach ($this->m_models as $l_index => $l_model) {
            // Determine if chapter shall be in a new page or not
            if (($l_model->get_new_page() == 1) && ($l_model->get_pos() != '1.')) {
                $this->m_formatter->addNewPage();
            }

            $l_text = $l_model->get_text();

            // Attach headline to formatted document.
            if ($this->m_options['general.headlines']) {
                $this->m_formatter->addHeadline($l_model->get_title(), $l_model->get_pos(), $l_model->get_level());

                // We add "div" elements around the text, so that TCPDF will add more margin around the blocks.
                $l_text = '<div>' . $l_text . '</div>';
            }

            // Attach content to formatted document.
            $this->m_formatter->addContent($l_text, $l_model->get_pos(), $l_model->get_level());
        }

        $this->m_formatter->afterExport();

        return $this;
    }

    /**
     *
     * @param   string    $p_filename
     * @param string|null $filePath
     *
     * @return  isys_document_export_pdf
     */
    public function write($p_filename, $filePath = null)
    {
        $this->m_formatter->save(($filePath !== null ? rtrim($filePath, '/') . '/' . $p_filename . '.' . $this->get_file_extension() : $this->get_filepath($p_filename)));

        return $this;
    }

    /**
     *
     * @param   string  $p_filename
     * @param   boolean $p_inline
     *
     * @return  isys_document_export_pdf
     */
    public function send($p_filename, $p_inline = false)
    {
        $this->m_formatter->send($p_filename . '.pdf', $p_inline);

        return $this;
    }

    /**
     * Mimetype of our file.
     *
     * @return  string
     */
    public function get_mimetype()
    {
        return 'application/pdf';
    }

    /**
     * Extension.
     *
     * @return  string
     */
    public function get_file_extension()
    {
        return 'pdf';
    }

    /**
     * Initialize.
     */
    protected function init()
    {
        // Setting default styles.
        $this->prepareStylesheet();
    }

    /**
     * @return void
     */
    private function prepareStylesheet()
    {
        // @see  DOKU-304 Preparing some default styles.
        $style = 'p { margin: 0 0 10px 0; }
            table { width: 100%; } 
            code { font-family: courier; }
            ins { text-decoration: underline; } 
            blockquote { padding: 5px 20px; margin-left: 20px; border-left: 3px solid #ccc; } 
            .marker { background-color: #ff0; } 
            .text-monospace, .font-monospace { font-family: courier; } ';

        // @see  DOKU-308  Pass the defined headline-sizes.
        foreach ($this->m_options as $key => $value) {
            if (preg_match('~general\.h([1-6])\.size~', $key, $matches)) {
                $style .= 'h' . $matches[1] . ' { font-size: ' . $value . 'pt; } ';
            }
        }

        $this->set_style($style);
    }
}
